from .code import get_file as __get_file

def lexicon():
    return __get_file("words.json")

def feature_lists():
    return __get_file("featurelists.json")

def feature_types():
    return __get_file("featuretypes.json")

def lexicon_pos():
    return __get_file("lexicon_lf.json")

def ontology():
    return __get_file("ontology.json")

def syntax_templates():
    return __get_file("syntax_templates.json")



import jsontrips

assert type(jsontrips.lexicon()) is dict
assert type(jsontrips.feature_lists()) is dict
assert type(jsontrips.feature_types()) is dict
assert type(jsontrips.lexicon_pos()) is dict
assert type(jsontrips.ontology()) is dict
assert type(jsontrips.syntax_templates()) is dict

assert type(jsontrips.lexicon()) is dict
assert type(jsontrips.feature_lists()) is dict
assert type(jsontrips.feature_types()) is dict
assert type(jsontrips.lexicon_pos()) is dict
assert type(jsontrips.ontology()) is dict
assert type(jsontrips.syntax_templates()) is dict

assert len(jsontrips.lexicon()) > 0
assert len(jsontrips.feature_lists()) > 0
assert len(jsontrips.feature_types()) > 0
assert len(jsontrips.lexicon_pos()) > 0
assert len(jsontrips.ontology()) > 0
assert len(jsontrips.syntax_templates()) > 0





from setuptools import setup, find_packages
from setuptools.command.install import install


with open("README.md", "r") as fh:
    long_description = fh.read()


if __name__ == "__main__":
        setup(
                name='jsontrips',
                version="0.1.28",
                author="Rik",
                author_email="rbose@cs.rochester.edu",
                description="A basic package",
                long_description=long_description,
                long_description_content_type="text/markdown",
                url="https://github.com/mrmechko/jsontrips",
                packages=find_packages(exclude=["test", "code"]),
                package_data={
                    "jsontrips": ['data/*.json']
                },
                classifiers=[
                    "Programming Language :: Python :: 3",
                    "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
                    "Operating System :: OS Independent"
                ]
        )



import logging
logging.basicConfig()

version = "0.1.28"

import os
import pkg_resources
import json

def get_file(name):
    logging.info("Getting {} - version {}".format(name, version))
    return json.loads(pkg_resources.resource_string(__name__, os.path.join("data", name)).decode('utf-8'))
